Module session

Module session 

Browser session facade.

This module exposes the stable session type while delegating execution to the native TetherScript backend when that feature is enabled.

Structs

BrowserSession
Cloneable browser session handle. Cloneable handle for executing browser commands.

Functions

detect_browser
Return the detected external browser executable, if one is required.