Browser session facade.
This module exposes the stable session type while delegating execution to the native TetherScript backend when that feature is enabled.
Structs
- Browser
Session - Cloneable browser session handle. Cloneable handle for executing browser commands.
Functions
- detect_
browser - Return the detected external browser executable, if one is required.